import type { RequestHandler } from '@sveltejs/kit';
import { Strike, User } from '$lib/server/database';
import { env } from '$env/dynamic/private';

export const GET = (async ({ url }) => {
	if (env.REPORT_SECRET && url.searchParams.get('secret') !== env.REPORT_SECRET)
		return new Response(null, { status: 401 });

	const uuid = url.searchParams.get('uuid');
	if (uuid == null) return new Response(null, { status: 400 });

	const user = await User.findOne({ where: { uuid: uuid } });
	if (user == null) return new Response(null, { status: 400 });

	const strike = await Strike.findOne({ where: { user_id: user.id } });

	return new Response(
		JSON.stringify({
			uuid: user.uuid,
			username: user.username,
			firstname: user.firstname,
			lastname: user.lastname,
			ban_until: strike ? strike.ban_until.getTime() / 1000 : null
		}),
		{ status: 200 }
	);
}) satisfies RequestHandler;
